<?php
/* $Id: japanese-euc.inc.php,v 2.151.2.2 2006/08/30 10:43:14 nijel Exp $ */

/**
 * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
 *               Tadashi Jokagi <elf2000 at users.sourceforge.net>
 *               Kenichi Ishigaki <ishigaki at tcool.org>
 */

$charset = 'euc-jp';
$text_dir = 'ltr';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Х', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');

$mysql_4_1_doc_lang = 'ja';

$day_of_week = array('', '', '', '', '', '', '');
$month = array('1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 ');
// See http://www.php.net/manual/ja/function.strftime.php to define the
// variable below
$datefmt = '%Y ǯ %B %d  %H:%M';
$timespanfmt = '%s  %s  %s ʬ %s ';

$strAbortedClients = 'Ǥޤ';
$strAbsolutePathToDocSqlDir = 'docSQL ؤХѥꤷƤ';
$strAccessDenied = 'ϵݤޤ';
$strAccessDeniedCreateConfig = '餯ͳϡեƤʤǤ%1$såȥåץץ%2$s ѤƤҤȤĺ뤳ȤǤޤ';
$strAccessDeniedExplanation = 'MySQL Ф³褦Ȥޤ³䤵ޤconfig.inc.php Υۥȡ桼ӥѥɤMySQL ФδԤͿ줿Ȱפ뤫ǧƤ';
$strAction = '';
$strAddAutoIncrement = 'AUTO_INCREMENTͤɲä';
$strAddClause = '%sɲ';
$strAddConstraints = '¤ɲä';
$strAddDeleteColumn = 'եɲá';
$strAddDeleteRow = 'Ԥɲá';
$strAddedColumnComment = 'Υɲäޤ';
$strAddedColumnRelation = 'Υ졼ɲäޤ';
$strAddFields = '%s ĤΥեɤɲä';
$strAddHeaderComment = 'إåإॳȤɲ (\\n ǲ)';
$strAddIntoComments = 'ɲå';
$strAddNewField = 'եɤɲä';
$strAddPrivilegesOnDb = 'ǡ١øɲä';
$strAddPrivilegesOnTbl = 'ơ֥øɲä';
$strAddSearchConditions = 'ʸɲäƤ("where"ʸ):';
$strAddToIndex = ' &nbsp;%s&nbsp; 򥤥ǥåɲäޤ';
$strAddUser = '桼ɲä';
$strAddUserMessage = '桼ɲäޤ';
$strAdministration = '';
$strAffectedRows = 'ƶ줿Կ:';
$strAfter = 'ꥫθ %s';
$strAfterInsertBack = '';
$strAfterInsertNewInsert = '쥳ɤɲä';
$strAfterInsertNext = 'ιԤԽ';
$strAfterInsertSame = 'Υڡ';
$strAll = '';
$strAllowInterrupt = '»֤ŤƤ뤳Ȥ򥹥ץȤΤ硢ݡȤؤγߤĤޤ礭ʥե򥤥ݡȤΤ褤ʤ⤷ޤ󤬡ϥȥ󥶥Ȥˤʤޤ';
$strAllTableSameWidth = '٤ƤΥơ֥Ʊɽޤ?';
$strAlterOrderBy = 'ơ֥֤ξ';
$strAnalyzeTable = 'ơ֥ʬϤ';
$strAnd = 'AND';
$strAndThen = 'Ƥθ';
$strAnIndex = 'ǥå%sɲäƤޤ';
$strAny = '٤';
$strAnyHost = '٤ƤΥۥ';
$strAnyUser = '٤ƤΥ桼';
$strApproximateCount = 'ᤤ⤷ޤFAQ 3.11 򻲾ȤƤ';
$strAPrimaryKey = '祭 %s ɲäޤ';
$strArabic = 'ӥ';
$strArmenian = '˥';
$strAscending = '';
$strAtBeginningOfTable = 'ơ֥Ƭ';
$strAtEndOfTable = 'ơ֥';
$strAttr = 'ɽ';
$strAutodetect = 'ưΤ';
$strAutomaticLayout = 'ư쥤';

$strBack = '';
$strBaltic = 'ХȽ';
$strBeginCut = 'ڤ곫';
$strBeginRaw = 'RAW ';
$strBinary = ' Хʥ ';
$strBinaryDoNotEdit = ' Хʥ - Ǥޤ';
$strBinaryLog = 'Хʥ';
$strBinLogEventType = '٥ȥ';
$strBinLogInfo = '';
$strBinLogName = '';
$strBinLogOriginalPosition = 'ΰ';
$strBinLogPosition = '';
$strBinLogServerId = ' ID';
$strBookmarkAllUsers = '٤ƤΥ桼Υ֥åޡ򥢥Ǥ';
$strBookmarkCreated = '֥åޡ %s ޤ';
$strBookmarkDeleted = '֥åޡ˺ޤ';
$strBookmarkLabel = '٥';
$strBookmarkQuery = '֥åޡƤ SQL';
$strBookmarkReplace = '¸ߤƱΥ֥åޡִ';
$strBookmarkThis = 'SQL ֥åޡ';
$strBookmarkView = 'ɽΤ';
$strBrowseDistinctValues = '̤ͤɽ';
$strBrowse = 'ɽ';
$strBrowseForeignValues = 'ɽ';
$strBufferPool = 'Хåեס';
$strBufferPoolActivity = 'Хåեסγ';
$strBufferPoolUsage = 'Хåեסλ';
$strBufferReadMisses = 'ɤ߹ߥߥ';
$strBufferReadMissesInPercent = '% ɤ߹ߥߥ';
$strBufferWriteWaits = '񤭹Ԥ';
$strBufferWriteWaitsInPercent = '% ν񤭹Ԥ';
$strBulgarian = '֥륬ꥢ';
$strBusyPages = 'ӥʥڡ';
$strBzError = ' php С Bz2 ĥƤΤ phpMyAdmin ̥פǤޤphpMyAdmin Υե졼ե <code>$cfg[\'BZipDump\']</code>  <code>FALSE</code>ꤷƤBz2 ̵ǽȤˤ php ΥС夲Ʋphp Х %s ܺ١';
$strBzip = '"bzip "';

$strCalendar = '';
$strCanNotLoadExportPlugins = 'ݡȥץ饰ɤǤޤ󥹥ȡ뤵Ƥ뤫ǧƤ!';
$strCanNotLoadImportPlugins = 'ݡȥץ饰ɤ߹ޤ󡣥󥹥ȡǧƤ!';
$strCannotLogin = 'MySQL Ф˥Ǥޤ';
$strCantLoad = 'ʤĥҤΥեǤ,<br />PHP åƤ';
$strCantLoadRecodeIconv = 'ʸåѴԤˤȤ߹ޤƤʤ iconv ޤ GNU recode γĥɬפǤphp ˡγĥԤäƤphpMyAdmin ǤʸåѴ򤷤ʤˤƤ';
$strCantRenameIdxToPrimary = 'ǥå PRIMARY ѹǤޤ';
$strCantUseRecodeIconv = 'iconvlibiconvrecode_string ΤδؿѤǤޤphp åƤ';
$strCardinality = 'դͤο';
$strCaseInsensitive = 'ѻ羮̤ʤ';
$strCaseSensitive = 'ѻ羮̤';
$strCentralEuropean = '衼åѸ';
$strChange = 'ѹ';
$strChangeCopyMode = 'ƱøäΥ桼...';
$strChangeCopyModeCopy = '... ŤΤݻ';
$strChangeCopyModeDeleteAndReload = ' ... 桼ơ֥뤫ŤΤø˺Ƥӥɤ';
$strChangeCopyModeJustDelete = ' ... 桼ơ֥뤫ŤΤ';
$strChangeCopyModeRevoke = ' ... ŤΤͭø򤹤٤̵ˤǺ';
$strChangeCopyUser = 'ѹ / 桼ԡ';
$strChangeDisplay = 'ɽեɤǲ';
$strChangePassword = 'ѥɤѹ';
$strCharset = 'ʸå';
$strCharsetOfFile = 'եʸå:';
$strCharsets = 'ʸ';
$strCharsetsAndCollations = 'ʸåȤȾȹ';
$strCheckAll = '٤ƥå';
$strCheckOverhead = 'Сإåɤθ򤹤';
$strCheckPrivs = 'øΥå򤹤';
$strCheckPrivsLong = 'ǡ١ &quot;%s&quot; øå';
$strCheckTable = 'ơ֥å';
$strChoosePage = 'Խڡ򤷤Ƥ';
$strColComFeat = '󥳥ɽǽ';
$strCollation = 'ȹ';
$strColumnNames = '()';
$strColumnPrivileges = 'ø';
$strCommand = 'ޥ';
$strComments = '';
$strCommentsForTable = 'COMMENTS FOR TABLE';
$strCompatibleHashing = 'MySQL&nbsp;4.0 ߴ';
$strCompleteInserts = ' INSERT ʸ';
$strCompression = '';
$strCompressionWillBeDetected = 'ݡȤ줿ե밵̤ϡưŪ˸ΤǤ礦: %s';
$strConfigDefaultFileError = 'ǥեɤ߹ޤǤ: "%1$s"';
$strConfigFileError = 'phpMyAdmin եɤ߹ळȤǤޤ! <br />ʸˡ顼ȯե뤬Ĥޤ<br />Υ󥯤եľɤ߹ǡPHP Υ顼åǧƤ¿ξ硢ڤʸ䥻ߥ˺Ƥޤ<br />⤷Υڡ줿餹٤ƤޤԤäƤޤ';
$strConfigureTableCoord = 'ơ֥%sơ֥ĴƤ';
$strConnectionError = '³Ǥޤ: ̵Ǥ';
$strConnections = '³';
$strConstraintsForDumped = '׺ѥơ֥';
$strConstraintsForTable = 'ơ֥';
$strCookiesRequired = 'ϥåĤƤɬפޤ';
$strCopy = 'ԡ';
$strCopyDatabaseOK = 'ǡ١%sϡ%s˥ԡޤ';
$strCopyTable = 'ơ֥(database<b>.</b>table)˥ԡ:';
$strCopyTableOK = 'ơ֥%s%s˥ԡޤ';
$strCopyTableSameNames = 'Ʊơ֥˥ԡǤޤ!';
$strCouldNotKill = 'phpMyAdmin å %s λ뤳ȤǤޤǤ餯˽λƤޤ';
$strCreate = '';
$strCreateDatabaseBeforeCopying = 'ԡˡCREATE DATABASE';
$strCreateIndex = '&nbsp;%s&nbsp; Υǥå';
$strCreateIndexTopic = 'ǥå';
$strCreateNewDatabase = 'ǡ١';
$strCreateNewTable = 'ǡ١%s˥ơ֥򿷵';
$strCreatePage = 'ڡ';
$strCreatePdfFeat = 'PDF ǽ';
$strCreateUserDatabase = '桼ѥǡ١';
$strCreateUserDatabaseName = 'ƱΥǡ١Ƥ٤ƤøͿޤ';
$strCreateUserDatabaseNone = 'ʤ';
$strCreateUserDatabaseWildcard = '磻ɥɤǻꤵ줿ǡ١ˤ٤ƤøͿޤ(桼_%)';
$strCreationDates = '//դɲä';
$strCriteria = 'ʹߴ';
$strCroatian = '';
$strCSV = 'CSV';
$strCSVImportOptions = 'CSV ץ';
$strCSVOptions = 'CSV ץ';
$strCyrillic = 'ʸ';
$strCzech = '';
$strCzechSlovak = 'ΥХ';

$strDanish = 'ǥޡ';
$strData = 'ǡ';
$strDatabase = 'ǡ١';
$strDatabaseEmpty = 'ǡ١Ǥ!';
$strDatabaseExportOptions = 'ǡ١ݡȥץ';
$strDatabaseHasBeenDropped = 'ǡ١%s˺ޤ';
$strDatabaseNoTable = 'Υǡ١ϥơ֥ޤǤޤ!';
$strDatabases = 'ǡ١';
$strDatabasesDropped = 'ǡ١%sϺޤ';
$strDatabasesStats = 'ǡ١';
$strDatabasesStatsDisable = 'פ̵ˤ';
$strDatabasesStatsEnable = 'פĤ';
$strDatabasesStatsHeavyTraffic = ': ǡ١פĤ MySQL  WEBФδ֤ǽŤȥեåȯ뤫⤷ޤ';
$strDataDict = 'ǡ';
$strDataOnly = 'ǡΤ';
$strDataPages = 'ǡޤڡ';
$strDBComment = 'ǡ١Υ: ';
$strDBCopy = 'ǥǡ١򥳥ԡ';
$strDBGContext = 'ƥ';
$strDBGContextID = 'ƥID';
$strDBGHits = 'ҥå';
$strDBGLine = '';
$strDBGMaxTimeMs = '(ߥ)';
$strDBGMinTimeMs = 'Ǿ(ߥ)';
$strDBGModule = '⥸塼';
$strDBGTimePerHitMs = 'ҥåΨ(ߥ)';
$strDBGTotalTimeMs = '׻(ߥ)';
$strDbPrivileges = 'ǡ١ ø';
$strDBRename = '˥ǡ١ѹ';
$strDbSpecific = 'ǡ١';
$strDefault = '';
$strDefaultEngine = '%s ϡ MySQL ФΥǥեȥȥ졼󥸥Ǥ';
$strDefaultValueHelp = 'ǥեͤΤˡХåå奨פʤ 1 ĤͤƲ, ΥեޥåȤ: a';
$strDefragment = 'ơ֥Υǥե饰';
$strDelayedInserts = 'ٱ䥤󥵡ȤѤ';
$strDelete = '';
$strDeleteAndFlush = '桼øɤ';
$strDeleteAndFlushDescr = 'ϥꥢǤøɤΤǾ֤ޤ';
$strDeleted = '򤷤ޤ';
$strDeletedRows = '줿Կ:';
$strDeleteNoUsersSelected = '桼򤷤Ƥޤ!';
$strDeleting = '%s Ǥ';
$strDelimiter = 'ǥߥ';
$strDelOld = 'ߤΥڡϡϤ¸ߤʤơ֥˻ȤޤλȤǤ?';
$strDescending = '߽';
$strDescription = '';
$strDictionary = '';
$strDirtyPages = 'ʥڡ';
$strDisabled = '̵';
$strDisableForeignChecks = 'θ̵ˤ';
$strDisplayFeat = 'ơ֥ɽǽ';
$strDisplayOrder = 'ɽ:';
$strDisplayPDF = 'PDF ޤɽ򤹤';
$strDoAQuery = '"QUERY"¹ (磻ɥ: "%")';
$strDocu = 'ɥ';
$strDoYouReally = '˼¹ԤƤɤǤ?:';
$strDrop = '';
$strDropDatabaseStrongWarning = '˥ǡ١˲Ǥ礦!';
$strDropUsersDb = '桼Ʊĥǡ١';
$strDumpingData = 'ơ֥Υץǡ';
$strDumpSaved = 'פե %s ¸ޤ';
$strDumpXRows = '%s פޤ %s Ǥ';
$strDynamic = 'ʥߥå';

$strEdit = '';
$strEditPDFPages = 'PDF ڡԽ';
$strEditPrivileges = 'ø';
$strEffective = '¸';
$strEmpty = 'ˤ';
$strEmptyResultSet = 'MySQL ֤ͤޤ (㤨йԤä)';
$strEnabled = 'ͭ';
$strEncloseInTransaction = 'ȥ󥶥ǥݡȤϤ';
$strEncto = '󥳡ǥ󥰤Ѵ'; // encoding convert
$strEnd = 'Ǹ';
$strEndCut = 'ڤ꽪λ';
$strEndRaw = 'RAW λ';
$strEngineAvailable = '%s ϡ MySQL ФѲǽǤ';
$strEngineDisabled = '%s ϡ MySQL ФǤ̵ˤƤޤ';
$strEngines = '󥸥';
$strEngineUnsupported = ' MySQL Ф %s ȥ졼󥸥򥵥ݡȤƤޤ';
$strEnglish = 'Ѹ';
$strEnglishPrivileges = ' : MySQLøϱѸɽƤޤ';
$strError = '顼';
$strErrorInZipFile = 'ZIP ֤˥顼ޤ:';
$strErrorRenamingTable = 'ơ֥%1$s%2$s˥͡हȤ˥顼ȯޤ';
$strEscapeWildcards = '磻ɥɡ_ӡ%ʸ̤˻ѤȤϡ\ǥפƤ';
$strEsperanto = 'ݸ';
$strEstonian = 'ȥ˥';
$strExcelEdition = 'Excel μ';
$strExcelOptions = 'Excel ץ';
$strExecuteBookmarked = '֥åޡ줿Ȳ¹Ԥ';
$strExplain = 'SQL ʬϤ';
$strExport = 'ݡ';
$strExportMustBeFile = 'Υݡȷϥե¸ɬפޤ!';
$strExtendedInserts = 'ĥ INSERT ʸ';
$strExtra = '¾';

$strFailedAttempts = 'ߤϼԤޤ';
$strField = 'ե';
$strFieldHasBeenDropped = 'ե %s ˺ޤ';
$strFields = 'ե';
$strFieldsEmpty = ' եɿǤ ';
$strFieldsEnclosedBy = 'եɰϤߵ';
$strFieldsEscapedBy = 'եɤΥ׵';
$strFieldsTerminatedBy = 'եɶڤ국';
$strFileAlreadyExists = 'ե%sϴ˥Ф¸ߤޤեѹ뤫񤭥ץǧƤ';
$strFileCouldNotBeRead = 'եɤޤ';
$strFileNameTemplate = 'եΥƥץ졼';
$strFileNameTemplateDescription = 'ͤ %1$sstrftime%2$s ѤơȽǤޤäơֽ񼰤ʸѤ뤳ȤǤޤ˼ʸִǤ礦: %3$sΤޤޤ¾ΥƥȤϰݻǤ礦';
$strFileNameTemplateDescriptionDatabase = 'ǡ١';
$strFileNameTemplateDescriptionServer = '';
$strFileNameTemplateDescriptionTable = 'ơ֥';
$strFileNameTemplateRemember = 'ƥץ졼ȤФ';
$strFileToImport = 'ե򥤥ݡȤ';
$strFixed = '';
$strFlushPrivilegesNote = ': phpMyAdmin  MySQL øơ֥뤫ľܤ˥桼øޤ⤷ޥ˥奢øѹƤȡΥơ֥ƤȤϰۤʤ뤫⤷ޤ󡣤ξ硢³ޤ %s ø %s 򤹤ɬפޤ';
$strFlushQueryCache = 'Ȳ񥭥åեå夹';
$strFlushTable = 'ơ֥Υåˤ("FLUSH")';
$strFlushTables = '٤ƤΥơ֥եå夹(Ĥ)';
$strFontSize = 'եȥ';
$strFormat = 'եޥå';
$strFormEmpty = 'եǤͤޤǤ';
$strFreePages = 'ե꡼ʥڡ';
$strFullText = 'ʸ';
$strFunction = 'ؿ';
$strFunctions = 'ؿ';

$strGenBy = 'Ķ';
$strGeneralRelationFeat = '졼ǽ';
$strGenerate = '';
$strGeneratePassword = 'ѥɤ';
$strGenTime = 'λ';
$strGeorgian = '른';
$strGerman = 'ɥĸ';
$strGlobal = 'Х';
$strGlobalPrivileges = 'Хø';
$strGlobalValue = 'Х';
$strGo = '¹Ԥ';
$strGrantOption = '°Ѿ';
$strGreek = 'ꥷ';
$strGzip = '"gzip "';

$strHandler = '';
$strHasBeenAltered = 'ѹޤ';
$strHasBeenCreated = 'ޤ';
$strHaveToShow = 'ɽ뤿ˡʤƤҤȤĤΥ򤷤ʤФʤޤ';
$strHebrew = 'إ֥饤';
$strHexForBinary = 'Хʥեɤ 16 ʿѤ';
$strHome = 'ᥤڡ';
$strHomepageOfficial = 'phpMyAdmin ۡ';
$strHost = 'ۥ';
$strHostEmpty = 'ۥȤ϶Ǥ!';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 ݡȥץ';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 ݡȥץ';
$strHungarian = 'ϥ󥬥꡼';

$strIcelandic = 'ɸ';
$strId = 'ID';
$strIdxFulltext = 'ʸ';
$strIgnore = '̵';
$strIgnoreDuplicates = 'Ԥʣ̵뤹';
$strIgnoreInserts = 'INSERT IGNOREѤ';
$strIgnoringFile = 'ե̵ %s';
$strImport = 'ݡ';
$strImportDocSQL = 'docSQL ե륤ݡ';
$strImportFiles = 'ݡȥե';
$strImportFormat = 'ݡȺѥեν';
$strImportSuccessfullyFinished = 'ݡȤޤ%d ĤξȲ¹Ԥޤ';
$strIndex = 'ǥå';
$strIndexes = 'ǥå';
$strIndexHasBeenDropped = 'ǥå %s ޤ';
$strIndexName = 'ǥå&nbsp;:';
$strIndexType = 'ǥåμ&nbsp;:';
$strIndexWarningMultiple = '1 Ĥۤ INDEX  `%s` Ѥ˺ޤ';
$strIndexWarningPrimary = ' `%s`  PRIMARY  INDEX ΥξȤꤹΤϤ褷ޤ礦';
$strIndexWarningTable = 'ơ֥ `%s` Υǥå˴ؤǤ';
$strIndexWarningUnique = ' `%s`  UNIQUE  INDEX ΥξȤꤹΤϤ褷ޤ礦';
$strInnoDBAutoextendIncrementDesc = ' 줬äѤˤʤˡưĥơ֥륹ڡΥĥ뤿ʬ̤Ǥ';
$strInnoDBAutoextendIncrement = 'ưĥɲ';
$strInnoDBBufferPoolSize = 'Хåեѥ';
$strInnoDBBufferPoolSizeDesc = 'InnoDB åǡȤΥơ֥Υǥå˻ȤХåեΥǤ';
$strInnoDBDataFilePath = 'ǡե';
$strInnoDBDataHomeDir = 'ǡۡǥ쥯ȥ';
$strInnoDBDataHomeDirDesc = '٤Ƥ InnoDB ǡեѤΥǥ쥯ȥѥζʬǤ';
$strInnoDBPages = 'ڡ';
$strInnodbStat = 'InnoDB ơ';
$strInsecureMySQL = 'ʤΥե졼ե꤬ MySQL ǥեȤøȤˤʤäƤޤ (root 桼ǥѥɤʤ)  MySQL Ф⤳ΥǥեưƤΤǡԤФ̵ǤΥƥۡɬĤƤ';
$strInsertAsNewRow = 'ԤȤɲä';
$strInsertedRowId = '󥵡Ȥ ID:';
$strInsertedRows = 'ɲä줿Կ:';
$strInsert = 'ɲ';
$strInternalNotNecessary = '* InnoDB ¸ߤ硢졼ɬפǤϤޤ';
$strInternalRelations = '졼';
$strInUse = '';
$strInvalidAuthMethod = 'ʤǧˡꤷƤޤ:';
$strInvalidColumn = 'ʤ (%s) ꤵޤ!';
$strInvalidColumnCount = ' 0 礭ʤФޤ';
$strInvalidCSVFieldCount = 'CSV  ̵ʹܿޤ(:%d)';
$strInvalidCSVFormat = 'CSV  ̵ʽ񼰤ޤ(:%d)';
$strInvalidCSVParameter = 'CSV ݡȤΥѥ᡼̵Ǥ: %s';
$strInvalidDatabase = 'ǡ١Ǥ';
$strInvalidFieldAddCount = 'ʤȤҤȤĤΥեɤɲäʤФʤޤ';
$strInvalidFieldCount = 'ơ֥ϾʤȤҤȤĤΥեɤɬפǤ';
$strInvalidLDIImport = 'Υץ饰ϰ̺ѥݡȤ򥵥ݡȤƤޤ!';
$strInvalidRowNumber = '%d ʤֹǤ';
$strInvalidServerHostname = 'С%1$sΥۥȤ̵ǤĴƤ';
$strInvalidServerIndex = '̵ʥХǥåǤ: "%s"';
$strInvalidTableName = 'ơ֥뤬Ǥ';

$strJapanese = 'ܸ';
$strJoins = '';
$strJumpToDB = '&quot;%s&quot; ǡ١إ.';
$strJustDelete = 'øơ֥뤫桼¨';
$strJustDeleteDescr = '&quot;&quot; 桼øɤޤǥФ˥ǽǤ';

$strKanjiEncodConvert = 'Ѵ'; // kanji code convert
$strKeepPass = 'ѥɤѹʤ';
$strKeyCache = 'å';
$strKeyname = '';
$strKill = '';
$strKorean = 'ڹ';

$strLandscape = 'ɥ';
$strLanguage = '';
$strLanguageFileNotFound = 'ե%1$sĤޤ';
$strLanguageUnknown = 'θ: %1$s.';
$strLatchedPages = 'åƤڡ';
$strLatexCaption = 'ơ֥륭ץ';
$strLatexContent = 'ơ֥ __TABLE__ ';
$strLatexContinued = '(³)';
$strLatexContinuedCaption = '³Υơ֥륭ץ';
$strLatexIncludeCaption = 'ơ֥륭ץޤ';
$strLatexLabel = '٥륭';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX ץ';
$strLatexStructure = 'ơ֥ __TABLE__ ι¤';
$strLatvian = 'ȥӥ';
$strLDIImportOptions = 'LOAD DATA Ѥ CSV ΥݡȤ򤹤륪ץ';
$strLDI = 'LOAD DATA Ѥ CSV';
$strLDILocal = '륭ɤѤ';
$strLengthSet = 'Ĺ/å*';
$strLimitNumRows = 'ڡκ쥳ɿ';
$strLinesTerminatedBy = 'Ԥνü';
$strLinkNotFound = '󥯤Ĥޤ';
$strLinksTo = '';
$strLithuanian = 'ȥ˥';
$strLocalhost = '';
$strLocationTextfile = 'ƥȥեξ';
$strLogin = '';
$strLoginInformation = '';
$strLogout = '';
$strLogPassword = 'ѥ:';
$strLogServer = '';
$strLogUsername = '桼:';
$strLongOperation = 'ϻ֤ޤǤʤߤޤ?';

$strMaxConnects = '¹³';
$strMaximalQueryLength = 'ȲκĹ';
$strMaximumSize = '祵: %s%s';
$strMbExtensionMissing = 'mbstring PHP ĥϸĤޤǤޥХʸåȤѤƤ褦˸ޤphpMyAdmin  mbstring ĥʤǤʸΤʬ䤹뤳ȤǤޤͽʤ̤֤äƤ뤫⤷ޤ';
$strMbOverloadWarning = 'PHP  mbstring.func_overload ͭǤΥץ phpMyAdmin ȸߴʤĤΥǡ˲⤷ޤ!';
$strMIME_available_mime = 'ͭ MIME ';
$strMIME_available_transform = 'Ѵͭ';
$strMIME_description = '';
$strMIME_MIMEtype = 'MIME ';
$strMIME_nodescription = 'Ѵˤͭޤ<br />Ԥ%sΰ̣򤴳ǧ';
$strMIME_transformation = '֥饦Ѵ';
$strMIME_transformation_note = 'ѲǽѴץΰӤ MIME Ѵ˴ؤƤϡ%sѴ%s 򥯥åƤ';
$strMIME_transformation_options = 'Ѵץ';
$strMIME_transformation_options_note = 'ν񼰤ѤơѴץͤϤƤ: \'a\',\'b\',\'c\'...<br />Хåå("\")䥷󥰥륯("\'")ͤ˴ޤɬפ(\\\\xyza\\\'bΤ褦)ХååǥפƤ';
$strMIMETypesForTable = 'MIME TYPES FOR TABLE';
$strMIME_without = 'åΤǰ줿 MIME פϸ̤ѴؿäƤޤ';
$strModifications = 'ޤ';
$strModify = '';
$strModifyIndexTopic = 'ǥåѹ';
$strMoveTable = 'ơ֥(database<b>.</b>table)˰ư:';
$strMoveTableOK = 'ơ֥%s%s˰ưޤ';
$strMoveTableSameNames = 'Ʊơ֥˰ưǤޤ!';
$strMultilingual = '¿';
$strMyISAMDataPointerSize = 'ǡΥݥ󥿡';
$strMyISAMDataPointerSizeDesc = 'CREATE TABLE  MyISAM ơ֥˻Ѥ MAX_ROWS ץ󤬻ꤵʤΥХȻΥǥեȥݥ󥿡Ǥ';
$strMyISAMMaxExtraSortFileSize = 'ǥåѰեκ祵';
$strMyISAMMaxExtraSortFileSizeDesc = 'MyISAMΥǥå®ȤѤƥݥե礭åѤȤꤳ˻ꤷͰʾ礭ʤϡåˡȤޤ';
$strMyISAMMaxSortFileSize = 'ȥեκ祵';
$strMyISAMMaxSortFileSizeDesc = 'MyISAM ǥåκƺǻѤ뤳Ȥ줿 MySQL եκ祵Ǥ (REPAIR TABLE 桢ALTER TABLE  LOAD DATA INFILE)';
$strMyISAMRecoverOptionsDesc = 'å夷 MyISAM ơ֥μưѥ⡼ɤǡеưץ --myisam-recover ꤷޤ';
$strMyISAMRecoverOptions = 'ư⡼';
$strMyISAMRepairThreads = 'åɤν';
$strMyISAMRepairThreadsDesc = '⤷ͤ 1 ʾʤ顢MyISAM ơ֥ΥǥåϥȽνʿԤ(켫Ȥγƥǥå)ޤ';
$strMyISAMSortBufferSize = 'ȥХåե';
$strMyISAMSortBufferSizeDesc = 'ΥХåեϡREPAIR TABLE δ֤ MyISAM ǥå򥽡Ȥ硢ޤ CREATE INDEX  ALTER TABLE ȥǥåˡդޤ';
$strMySQLCharset = 'MySQL ʸå';
$strMysqlClientVersion = 'MySQL 饤ȥС';
$strMySQLConnectionCollation = 'MySQL ³ȹ';
$strMySQLSaid = 'MySQLΥå: ';
$strMySQLShowProcess = 'MySQL ץɽ';
$strMySQLShowStatus = 'MySQL Υ󥿥';
$strMySQLShowVars = 'MySQL Υƥѿ';

$strName = '';
$strNext = '';
$strNo = '';
$strNoActivity = '%s ðʾ򤷤ޤǤ٥򤷤Ƥ';
$strNoDatabases = 'ǡ١';
$strNoDatabasesSelected = 'ǡ١򤵤Ƥޤ';
$strNoDataReceived = 'ݡȤǡǤޤǤե뤬Ƥʤե륵PHPǵĤ줿ͤĶƤޤFAQ 1.16';
$strNoDescription = 'Ҥޤ';
$strNoDetailsForEngine = 'Υȥ졼󥸥ˤͭʥơξܺپϤޤ';
$strNoDropDatabases = 'DROP DATABASEơȥȤ϶ػߤ';
$strNoExplain = 'SQL ʬϤФ';
$strNoFilesFoundInZip = 'ZIP ˥ե뤬Ĥޤ!';
$strNoFrames = 'phpMyAdmin <b>ե졼</b>򥵥ݡȤ֥饦ǤѤ򤪴ᤷޤ';
$strNoIndex = 'ǥåꤵƤޤ';
$strNoIndexPartsDefined = 'ǥåʬꤵƤޤ';
$strNoModification = 'ѹ̵';
$strNone = '̵';
$strNoOptions = 'ν񼰤ϥץ󤬤ޤ';
$strNoPassword = 'ѥ̵';
$strNoPermission = 'ե%s¸ѡߥå򥦥֥ФϻäƤޤ';
$strNoPhp = 'PHP ̵';
$strNoPrivileges = 'ø̵';
$strNoRights = 'øäƤʤΤǤޤ';
$strNoRowsSelected = 'Ԥ򤵤ޤǤ';
$strNoSpace = 'ե%s¸ˤ϶̤ʬǤ';
$strNoTablesFound = 'ߤΥǡ١˥ơ֥Ϥޤ';
$strNoThemeSupport = 'ơޤ򥵥ݡȤƤޤȥơޥǥ쥯ȥ%sǧƤ';
$strNotNumber = 'ϿͤǤϤޤ';
$strNotOK = 'OK ǤϤޤ';
$strNotSet = 'ơ֥<b>%s</b>Ĥʤ%s ꤵƤޤ';
$strNoUsersFound = '桼ϸĤޤǤ';
$strNoValidateSQL = 'SQL ڤ򥹥å';
$strNull = '(NULL)';
$strNumberOfFields = 'եɿ';
$strNumSearchResultsInTable = 'ơ֥ <i>%2\$s</i>  %2\$s פޤ';
$strNumSearchResultsTotal = '<b>:</b> <i>%s</i> Ĥޤ';
$strNumTables = 'ơ֥';

$strOK = 'OK';
$strOpenDocumentSpreadsheet = 'ץåɥȤ򳫤';
$strOpenDocumentSpreadsheetOptions = 'ץåɥȤ򳫤ȤΥץ';
$strOpenDocumentText = 'ƥȤ򳫤';
$strOpenDocumentTextOptions = 'ƥȤ򳫤ȤΥץ';
$strOpenNewWindow = ' phpMyAdmin Υɥ򳫤';
$strOperations = '';
$strOperator = '';
$strOptimizeTable = 'ơ֥Ŭ';
$strOr = 'ޤ';
$strOverhead = 'Сإå';
$strOverwriteExisting = 'ե뤬¸ߤϾ';

$strPageNumber = 'ڡֹ:';
$strPagesToBeFlushed = 'եå夵줿ڡ';
$strPaperSize = '極';
$strPartialImport = 'ʬŪʥݡ';
$strPartialText = 'ʬŪʸ';
$strPassword = 'ѥ';
$strPasswordChanged = '%s Υѥɤѹޤ';
$strPasswordEmpty = 'ѥɤǤ';
$strPasswordHashing = 'ѥɥϥå';
$strPasswordNotSame = 'ѥɤƱǤϤޤ';
$strPdfDbSchema = 'ǡ١%sΥ - ڡ %s';
$strPdfInvalidTblName = '"%s" ơ֥뤬ޤ!';
$strPdfNoTables = 'ơ֥뤬ޤ';
$strPDFOptions = 'PDF ץ';
$strPDF = 'PDF';
$strPDFReportExplanation = '(ñơ֥ΥǡޤݡȤޤ)';
$strPDFReportTitle = 'ݡȤ';
$strPerHour = '';
$strPerMinute = '/ʬ';
$strPerSecond = '/';
$strPersian = 'ڥ륷';
$strPhoneBook = 'Ģ';
$strPHP40203 = 'ޥХʸ(mbstring)ΰ˽ʥХΤ PHP 4.2.3 ȤäƤޤPHP ΥХݡ 19404 ֤ǤphpMyAdmin Ѥʤ顢ΥС PHP Ϥᤷޤ...ȸѥå򤢤Ƥʤưޤ';
$strPhp = 'PHP ɤκ';
$strPHPVersion = 'PHP С';
$strPmaDocumentation = 'phpMyAdmin Υɥ';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> ɬեꤷƤ!';
$strPolish = 'ݡɸ';
$strPortrait = 'ݡȥ쥤';
$strPos1 = 'ǽ';
$strPrevious = '';
$strPrimary = '';
$strPrimaryKeyHasBeenDropped = '祭ޤ';
$strPrimaryKeyName = '祭... PRIMARY ǤϤʤФޤ';
$strPrimaryKeyWarning = '("PRIMARY"Ϥ礦ɼ祭ǤϤʤФޤ';
$strPrint = '';
$strPrintView = 'Ѥɽ';
$strPrintViewFull = 'ӥ塼 (ƥȤޤ)';
$strPrivDescAllPrivileges = 'GRANT ٤Ƥøޤߤޤ';
$strPrivDescAlter = '¸ߤơ֥빽¤ѹĤޤ';
$strPrivDescAlterRoutine = 'ȥɥ롼ѹ˴Ĥޤ';
$strPrivDescCreateDb = 'ǡ١ơ֥κĤޤ';
$strPrivDescCreateRoutine = 'ȥɥ롼κĤޤ';
$strPrivDescCreateTbl = 'ơ֥κĤޤ';
$strPrivDescCreateTmpTable = 'ƥݥ꡼ơ֥κĤޤ';
$strPrivDescCreateUser = '桼Ȥκ˴ѹĤޤ';
$strPrivDescCreateView = 'ӥ塼κĤޤ';
$strPrivDescDelete = 'ǡκĤޤ';
$strPrivDescDropDb = 'ǡ١ȥơ֥κĤޤ';
$strPrivDescDropTbl = 'ơ֥κĤޤ';
$strPrivDescExecute5 = 'ȥɥ롼μ¹ԤĤޤ';
$strPrivDescExecute = 'ȥɥץ㡼¹Ԥ뤳ȤĤޤ MySQL ǤǤϰ̣ޤ';
$strPrivDescFile = 'ǡΥݡȡǡΥեؤΥݡȤĤޤ';
$strPrivDescGrant = 'øơ֥Υɤʤ˥桼øɲäĤޤ';
$strPrivDescIndex = 'ǥåκĤޤ';
$strPrivDescInsert = 'ǡؤĤޤ';
$strPrivDescLockTables = 'ߤΥåɤΥå󥰥ơ֥Ĥޤ';
$strPrivDescMaxConnections = '1 ˿³ǽʿ¤ޤ';
$strPrivDescMaxQuestions = '1 ˥Ф˾Ȳ¤ޤ';
$strPrivDescMaxUpdates = '1 ˥ơ֥롢ǡ١ФƤѹȯ륳ޥɤο¤ޤ';
$strPrivDescMaxUserConnections = '桼Ʊ³¤ޤ';
$strPrivDescProcess3 = '¾Υ桼ץߤǤ뤳ȤĤޤ';
$strPrivDescProcess4 = 'ץδʾȲɽĤޤ';
$strPrivDescReferences = ' MySQL СǤϰ̣ޤ';
$strPrivDescReload = 'ФΥɡåΥꥢĤޤ';
$strPrivDescReplClient = '졼֤ޥ׵Ǥ븢桼Ϳޤ';
$strPrivDescReplSlave = 'ץꥱ󥹥졼֤ɬפǤ';
$strPrivDescSelect = 'ǡɤ߽Ф';
$strPrivDescShowDb = 'ǡ١δʰؤΥͿޤ';
$strPrivDescShowView = 'Ȳ SHOW CREATE VIEW μ¹ԤĤޤ';
$strPrivDescShutdown = 'ФΥåȥĤޤ';
$strPrivDescSuper = '³ãƤ³Ĥޤ¿δϥХѿ¾桼ץνλǤ褦꤬ɬפǤ';
$strPrivDescUpdate = 'ǡνĤޤ';
$strPrivDescUsage = 'øޤ';
$strPrivileges = 'ø';
$strPrivilegesReloaded = 'øϥɤޤ';
$strProcedures = 'ץ';
$strProcesses = 'ץ';
$strProcesslist = 'ץ';
$strProtocolVersion = 'ץȥС';
$strPutColNames = 'ǽ 1 ܤ˥եɤɲä';

$strQBE = 'Ȳ';
$strQBEDel = '';
$strQBEIns = '';
$strQueryCache = 'Ȳ񥭥å';
$strQueryFrame = 'Ȳ񥦥ɥ';
$strQueryOnDb = 'ǡ١ SQL <b>%s</b>:';
$strQueryResultsOperations = 'Ȳ';
$strQuerySQLHistory = 'SQL ';
$strQueryStatistics = '<b>Ȳ</b>: ư %s ĤξȲ񤬥ФƤޤ';
$strQueryTime = 'Ȳμ¹Ի %01.4f ';
$strQueryType = 'Ȳ񥿥';
$strQueryWindowLock = 'ɥγ餳ξȲ񤭴Ǥޤ';

$strReadRequests = 'ɤ߹ߥꥯȿ';
$strReceived = '';
$strRecords = '쥳ɿ';
$strReferentialIntegrity = 'ܤΥå:';
$strRefresh = '';
$strRelationalSchema = '졼ʥ륹';
$strRelationNotWorking = 'phpMyAdmin ȼǽǤ졼ǽ뤿Υ󥯥ơ֥뤬ͭˤʤäƤޤ󡣤褹ˤ %s%s 򥯥åƸȯƤ';
$strRelations = '졼';
$strRelationsForTable = 'RELATIONS FOR TABLE';
$strRelationView = '졼ɽ';
$strReloadingThePrivileges = 'øɤ߹Ǥ';
$strReloadPrivileges = 'MySQL Υ';
$strRemoveSelectedUsers = '򤵤줿桼ޤ';
$strRenameDatabaseOK = 'ǡ١%sϡ%s˾ѹޤ';
$strRenameTable = 'ơ֥ѹ';
$strRenameTableOK = '%s%sѹޤ';
$strRepairTable = 'ơ֥줹';
$strReplaceNULLBy = 'NULL ʸ֤';
$strReplaceTable = 'եǥơ֥֤';
$strReplication = 'ץꥱ';
$strReset = 'ꥻå';
$strResourceLimits = '꥽';
$strReType = '';
$strRevoke = 'ѻ';
$strRevokeAndDelete = '桼ͭø򤹤٤˴ƺ';
$strRevokeAndDeleteDescr = '桼øɤ߹ߤޤ USAGE øΤޤޤǤ';
$strRevokeMessage = '%s øäޤ';
$strRomanian = '롼ޥ˥';
$strRowLength = 'ԤĹ';
$strRows = '';
$strRowsFrom = 'Ϲ';
$strRowSize = ' ԤΥ ';
$strRowsModeFlippedHorizontal = 'ʿ (žإå)';
$strRowsModeHorizontal = 'ʿ';
$strRowsModeOptions = ': %s : %s 󤺤ĥإå򷫤֤ɽ';
$strRowsModeVertical = 'ľ';
$strRowsStatistic = 'Ԥ';
$strRunning = '¹Ǥ %s';
$strRunQuery = 'Ȳμ¹Ԥ';
$strRunSQLQuery = 'ǡ١%s SQL ¹Ԥ';
$strRunSQLQueryOnServer = 'С%s SQL ¹Ԥ';
$strRussian = '';

$strSave = '¸';
$strSaveOnServer = 'оΥǥ쥯ȥ%s¸';
$strScaleFactorSmall = '1 ڡ˿ɽ֤뤿ˤ礭᤮ޤ';
$strSearch = '';
$strSearchFormTitle = 'ǡ١򸡺';
$strSearchInTables = 'ơ֥λ:';
$strSearchNeedle = 'ñ졢ޤ (磻ɥɤ: "%"):';
$strSearchOption1 = '줫ñޤ';
$strSearchOption2 = '٤Ƥñޤ';
$strSearchOption3 = 'Τʥե졼';
$strSearchOption4 = 'ɽ';
$strSearchResultsFor = ' "<i>%s</i>" %s:';
$strSearchType = ':';
$strSecretRequired = 'եϺ̩ѥե졼ɬפȤޤ(blowfish_secret)';
$strSelectADb = 'ǡ١򤷤Ƥ';
$strSelectAll = '';
$strSelectBinaryLog = '򤷤Хʥ';
$strSelectFields = 'եɤ(1 İʾ):';
$strSelectNumRows = 'Ȳ';
$strSelectTables = 'ơ֥';
$strSend = 'ե¸';
$strSent = '';
$strServer = '';
$strServerChoice = 'Ф򤹤';
$strServerNotResponding = 'Фȿޤ';
$strServers = '';
$strServerStatus = '󥿥';
$strServerStatusDelayedInserts = 'ٱ䥤󥵡';
$strServerStatusUptime = ' MySQL Ф %s ưǡ%s ˵ưƤޤ';
$strServerTabVariables = 'ѿ';
$strServerTrafficNotes = '<b>Хȥեå</b>: Υơ֥ MySQL ФưƤΥͥåȥȥեåפɽޤ';
$strServerVars = 'ѿ';
$strServerVersion = 'ФΥС';
$strSessionValue = 'å';
$strSetEnumVal = 'եɥפenumϡsetξͤˤν񼰤ȤäϤƤ: \'a\',\'b\',\'c\'...<br />Хåå"\"ϥȡ"\'"ϤȡƬ˥ХååդƲ(: \\\\xyz⤷ϡa\\\'b)';
$strShowAll = '٤ɽ';
$strShowColor = 'ɽ';
$strShowDatadictAs = 'ǡ';
$strShow = 'ɽ';
$strShowFullQueries = 'ʾȲɽ';
$strShowGrid = 'åɤɽ';
$strShowingBookmark = '֥åޡ';
$strShowingRecords = '쥳ɤɽ';
$strShowOpenTables = 'Ƥơ֥ɽ';
$strShowPHPInfo = 'PHP ';
$strShowSlaveHosts = '졼֥ۥȤɽ';
$strShowSlaveStatus = '졼֤ξ֤ɽ';
$strShowStatusBinlog_cache_disk_useDescr = 'ƥݥХʥåѤ褦Ȥơbinlog_cache_sizeͤĶᤷᡢȥ󥶥ΥơȥȤƥݥե¸ȥ󥶥ο';
$strShowStatusBinlog_cache_useDescr = 'ХʥåѤοǤ';
$strShowStatusCreated_tmp_disk_tablesDescr = 'ʸ¹˥ФˤäƼưŪ˥ǥ˺줿ơ֥οǤCreated_tmp_disk_tables 礭硢ΰơ֥ǥ١Ѥ˥١ˤ褦ˡ tmp_table_size 䤷Ǥ礦';
$strShowStatusCreated_tmp_filesDescr = 'mysqld ϤɤΰŪեǤ';
$strShowStatusCreated_tmp_tablesDescr = 'Фǹʸμ¹ԤˤäƼưŪ˺줿ΰơ֥ο';
$strShowStatusDelayed_errorsDescr = '㴳Υ顼ȯ INSERT DELAYED 񤫤줿ԿǤ (餯νʣ)';
$strShowStatusDelayed_insert_threadsDescr = ' INSERT DELAYED ϥɥ顼åɤοINSERT DELAYED ŬѤۤʤơ֥οͭΥåɤѰդޤ';
$strShowStatusDelayed_writesDescr = 'INSERT DELAYED 񤭹ߤ򤷤Ǥ';
$strShowStatusFlush_commandsDescr  = 'FLUSH ʸ¹ԤǤ';
$strShowStatusHandler_commitDescr = 'COMMIT ʸǤ';
$strShowStatusHandler_deleteDescr = 'ơ֥뤫Ǥ';
$strShowStatusHandler_discoverDescr = 'MySQLФNDB饹ȥ졼󥸥ĥơ֥ˤĤƤξäƤ뤫䤤碌뤳ȤǤޤϳȸƤФƤޤHandler_discoverϡ줿ơ֥ο򼨤ޤ';
$strShowStatusHandler_read_firstDescr = 'ǥåϤΥȥɤ߹Ǥ줬⤤硢ϥФ¿δʥǥåԤäƤȼޤ㤨СSELECT col1 FROM foo col1 ϥǥåȲꤷޤ';
$strShowStatusHandler_read_keyDescr = '˴ŤƹԤɤ߹׵οǤ줬⤤硢ϤʤξȲȥơ֥뤬Ŭڤ˥ǥåդƤȤ褤ɽǤ';
$strShowStatusHandler_read_nextDescr = 'ν̤˹ԤɤǤꥯȤοͤϰϤĤƥǥåȲ񤷤Ƥ뤫ǥåԤäƤȤޤ';
$strShowStatusHandler_read_prevDescr = 'ν̤˹Ԥ̤äɤǤꥯȤοɤ߹ߤϼORDER BY ... DESCŬȤѤޤ';
$strShowStatusHandler_read_rndDescr = 'ꤵ줿֤ɤǤꥯȤοͤϷ̤򥽡ȤɬפȲ̤˹Ԥȹ⤯ʤޤ餯ơ֥Τ򥹥󤷤ʤФʤʤȲ̤˹ԤäƤ뤫ŬڤѤƤʤjoinԤäƤΤȻפޤ';
$strShowStatusHandler_read_rnd_nextDescr = 'ǡեμιԤɤ߹׵οǤʤ¿Υơ֥륹򤷤Ƥ硢Ϲ⤤Ǥ̤ˤϡʤΥơ֥뤬Ŭڤ˥ǥåդʤȲ񤬥ǥåѤ褦˽񤫤ƤʤȤ򼨺ޤ';
$strShowStatusHandler_rollbackDescr = ' ROLLBACK ʸοǤ';
$strShowStatusHandler_updateDescr = 'ơ֥ιԤι׵ᤷǤ';
$strShowStatusHandler_writeDescr = 'ơ֥˹Ԥ׵ᤷǤ';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'ǡޤڡοǤ (dirty or clean).';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'ߤαڡοǤ';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'եå夵뤳Ȥ׵ᤷХåեסڡοǤ';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'ڡǤ';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'InnoDBХåեסǥåƤڡϸɤ߹Ǥ롢뤤Ͻ񤭹Ǥڡ뤤¾β餫ͳǥեå夷ǤʤʤäƤڡοǤ';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'ԥå䥢ץƥ֥ϥå奤ǥåȤäХإåɤΤǥӥˤʤäƤڡͤInnodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_dataȤǤ׻Ǥޤ';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'ڡΥХåեסΥιפǤ';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'InnoDBϤ֥ɤ߹ߤβϾȲ񤬥ơ֥ʬʽ֤ǥ󤹤Ȥȯޤ';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'InnoDBϤ󥷥ɤ߹ߤβInnoDB󥷥ʥեơ֥륹ԤȤȯޤ';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'InnoDB ԤäŪɤ߹׵οǤ';
$strShowStatusInnodb_buffer_pool_readsDescr = 'InnoDBХåեסƤѤǤ󥰥ڡɤ߹ߤԤʤФʤʤäɤ߹ߤβ';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = '̾InnoDBХåեסؤν񤭹ߤϥХå饦ɤǹԤޤڡɤ߹ߤʤԤɬפΤ˥꡼ʥڡʤϡޤΥڡեå夵ΤԤɬפޤΥ󥿤ϡΥȤβ򥫥ȤΤǤХåեסͤŬڤꤵƤСͤϾϤǤ';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'InnoDB Хåեסؤν񤭹ߤ򤷤Ǥ';
$strShowStatusInnodb_data_fsyncsDescr = 'ޤǤ fsync() Ǥ';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'ߤ fsync() αοǤ';
$strShowStatusInnodb_data_pending_readsDescr = 'ߤɤ߹αοǤ';
$strShowStatusInnodb_data_pending_writesDescr = 'ߤν񤭹αοǤ';
$strShowStatusInnodb_data_readDescr = 'ޤǤΥǡɤ߹̤Ǥ(ñ:Х)';
$strShowStatusInnodb_data_readsDescr = 'ɤ߹ߥǡοǤ';
$strShowStatusInnodb_data_writesDescr = '񤭹ߥǡοǤ';
$strShowStatusInnodb_data_writtenDescr = 'ޤǤΥǡν񤭹̤Ǥ(ñ:Х)';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'Ž񤭹ߤ¹Ԥ줿ȡŽ񤭹ߤȯڡ';
$strShowStatusInnodb_dblwr_writesDescr = 'Ž񤭹ߤ¹Ԥ줿ȡŽ񤭹ߤȯڡ';
$strShowStatusInnodb_log_waitsDescr = 'Хåե뤻ǺȤ³Ԥ˥եå夷ʤФʤʤʤäȯȤβ';
$strShowStatusInnodb_log_write_requestsDescr = '׵ᤵ줿񤭹ߤοǤ';
$strShowStatusInnodb_log_writesDescr = 'եؤʪŪʽߤοǤ';
$strShowStatusInnodb_os_log_fsyncsDescr = 'ե fsync 񤭹ߤ򤷤Ǥ';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'fsync ԤΥեǤ';
$strShowStatusInnodb_os_log_pending_writesDescr = 'եν񤭹ߤαǤ';
$strShowStatusInnodb_os_log_writtenDescr = 'ե˽񤭹ߤХȿǤ';
$strShowStatusInnodb_pages_createdDescr = '줿ڡοǤ';
$strShowStatusInnodb_page_sizeDescr = 'ѥΥڡ(ǥե 16KB)Ǥ¿ͤڡǥȤޤ; ڡϡ餬ưפ˥ХȤѴ뤳ȤĤޤ';
$strShowStatusInnodb_pages_readDescr = 'ɤ߹ߤڡǤ';
$strShowStatusInnodb_pages_writtenDescr = '񤭹ߤڡǤ';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'ԤƤåοǤ';
$strShowStatusInnodb_row_lock_time_avgDescr = 'åʿѻ֤Ǥ(ñ:ߥ)';
$strShowStatusInnodb_row_lock_timeDescr = 'γ˻Ȥ줿׻Ǥ(ñ:ߥ)';
$strShowStatusInnodb_row_lock_time_maxDescr = 'å֤Ǥ(ñ:ߥ)';
$strShowStatusInnodb_row_lock_waitsDescr = 'ԥåԤʤФʤʤäǤ';
$strShowStatusInnodb_rows_deletedDescr = 'InnoDB ơ֥뤫Ǥ';
$strShowStatusInnodb_rows_insertedDescr = 'InnoDB ơ֥Ǥ';
$strShowStatusInnodb_rows_readDescr = 'InnoDB ơ֥뤫ɤ߹Ǥ';
$strShowStatusInnodb_rows_updatedDescr = 'InnoDB ơ֥ǹ줿Ǥ';
$strShowStatusKey_blocks_not_flushedDescr = 'ѹ줬ޤǥ˥եå夵ƤʤåΥ֥åοǤϤĤƤ Not_flushed_key_blocks ȤΤޤ';
$strShowStatusKey_blocks_unusedDescr = 'å̤ѥ֥åοǤɤѤƤ뤫ꤹ뤿ˤͤѤ뤳ȤǤޤ';
$strShowStatusKey_blocks_usedDescr = 'åΥ֥åλѿǤͤϡޤƱ˻Ѥ줿֥åκؤǹǤ';
$strShowStatusKey_read_requestsDescr = 'å夫饭֥åɤ߹ꥯȿǤ';
$strShowStatusKey_readsDescr = 'ǥΥ֥åʪŪɤ߹߿ǤKey_reads 礭硢 key_buffer_size 餯ޤåߥΨ Key_reads/Key_read_requests ȤƷ׻뤳ȤǤޤ';
$strShowStatusKey_write_requestsDescr = 'åؤΥ֥åν񤭹ꥯȿǤ';
$strShowStatusKey_writesDescr = 'ǥؤΥ֥åʪŪʽ񤭹߿Ǥ';
$strShowStatusLast_query_costDescr = 'Ȳ񥪥ץƥޥˤäƷ׻줿Ǹ˥ѥ뤵줿ȲȤǤƱȲΰۤʤȲץΥȤӤΤΩޤǥե 0 ϡȲ񤬤ޤѥ뤵ƤʤȤ̣ޤ';
$strShowStatusNot_flushed_delayed_rowsDescr = 'Ȳ INSERT DELAY ν񤭹ԤιԿǤ';
$strShowStatusOpened_tablesDescr = 'Ƥơ֥οǤƤơ֥뤬¿硢餯ơ֥륭åͤޤ';
$strShowStatusOpen_filesDescr = 'ƤեοǤ';
$strShowStatusOpen_streamsDescr = 'Ƥ륹ȥ꡼οǤ (ȤƥεϿ˻Ѥޤ)';
$strShowStatusOpen_tablesDescr = 'Ƥơ֥οǤ';
$strShowStatusQcache_free_blocksDescr = 'Ȳ񥭥åζ֥åοǤ';
$strShowStatusQcache_free_memoryDescr = 'Ȳ񥭥åζ̤Ǥ';
$strShowStatusQcache_hitsDescr = 'åΥҥåȿǤ';
$strShowStatusQcache_insertsDescr = 'åɲä줿ȲǤ';
$strShowStatusQcache_lowmem_prunesDescr = 'Ȳ򥭥å夹뤿˥٤å夫줿ȲοξϾȲ񥭥åΥĴȤǤȲ񥭥å夬å夫ȲꤹݤˤϡǸ˻Ȥ줿郎ǤŤΤάȤޤ';
$strShowStatusQcache_not_cachedDescr = 'å夵ʤȲοǤ (åǤʤ query_cache_type ˤ륭å夷ʤ)';
$strShowStatusQcache_queries_in_cacheDescr = 'åϿ줿ȲοǤ';
$strShowStatusQcache_total_blocksDescr = 'Ȳ񥭥å֥åǤ';
$strShowStatusReset = 'ꥻå';
$strShowStatusRpl_statusDescr = 'ե륻եץꥱξ֤Ǥ (Ƥޤ)';
$strShowStatusSelect_full_joinDescr = 'ǥåѤʤοǤͤ 0 Ǥʤ硢ơ֥Υǥå褯ǧƤ';
$strShowStatusSelect_full_range_joinDescr = 'Ϣơ֥ϰϸѤοǤ';
$strShowStatusSelect_range_checkDescr = 'ʤjoinϳƹԤˤĤƥλ٤åΤǤʤ줬0ʳξϥơ֥Υǥå褯åƤˡ';
$strShowStatusSelect_rangeDescr = 'ǽΥơ֥ϰϤѤοǤ (줬礭Ƥ̾ϴǤϤޤ)';
$strShowStatusSelect_scanDescr = 'ǽΥơ֥δʥԤäοǤ';
$strShowStatusSlave_open_temp_tablesDescr = '졼 SQL åɤˤäƸ߳ƤŪơ֥οǤ';
$strShowStatusSlave_retried_transactionsDescr = 'ץꥱΥ졼 SQL åɤȥ󥶥ƻԤ(ư)׿';
$strShowStatusSlave_runningDescr = 'ΥФޥ³륹졼֤Ǥ硢 ON Ǥ';
$strShowStatusSlow_launch_threadsDescr = 'slow_launch_time ÿ֤äƺ줿åɤοǤ';
$strShowStatusSlow_queriesDescr = 'long_query_time ÿۤȲοǤ';
$strShowStatusSort_merge_passesDescr = 'ȥ르ꥺब¹ԤʤФʤʤäޡβͤ⤤ϡsort_buffer_sizeƥѿͤ䤹ȤƤƤ';
$strShowStatusSort_rangeDescr = 'ϰǥȤԤ줿';
$strShowStatusSort_rowsDescr = 'ȺѤιԿǤ';
$strShowStatusSort_scanDescr = 'ơ֥ˤԤ줿ȿǤ';
$strShowStatusTable_locks_immediateDescr = 'ơ֥å˼줿Ǥ';
$strShowStatusTable_locks_waitedDescr = 'ơ֥å˼Ǥʤä˥Ȥȯͤ⤯ѥեޥ󥹤꤬ƤϡޤȲŬƤǤʤ顢ơ֥ʬ䤹뤫ץꥱѤƤ';
$strShowStatusThreads_cachedDescr = 'åɥåΥåɿǤåҥåΨ Threads_created/Connections ȤƷ׻뤳ȤǤޤֻͤˤʤäƤȤ thread_cache_size 夲Ƥ';
$strShowStatusThreads_connectedDescr = '³οǤ';
$strShowStatusThreads_createdDescr = '³򰷤˺줿åɤοǤThreads_created 礭硢 thread_cache_size äȻפ⤷ޤ(̾褤åɼ򤷤Ƥ硢ϸʥѥեޥ󥹸Ϳޤ)';
$strShowStatusThreads_runningDescr = '꡼פƤʤåɤοǤ';
$strShowTableDimension = 'ơ֥礭ɽ';
$strShowTables = 'ơ֥ɽ';
$strShowThisQuery = ' ¹ԤȲ򤳤ɽ';
$strSimplifiedChinese = 'λ';
$strSingly = '(1 )';
$strSize = '';
$strSkipQueries = 'Ϥ饹åפ쥳(Ȳ)ο';
$strSlovak = 'Х';
$strSlovenian = '٥˥';
$strSocketProblem = '(ޤϡ MySQL ФΥåȤΤꤵޤ)';
$strSort = '';
$strSortByKey = 'ǥ';
$strSorting = '';
$strSpaceUsage = 'ǥ';
$strSpanish = 'ڥ';
$strSplitWordsWithSpace = 'ñϥڡʸ(" ")ǶڤäƲ';
$strSQLCompatibility = 'SQLߴ⡼';
$strSQLExportType = 'ݡȷ';
$strSQLImportOptions = 'SQL ץ';
$strSQLOptions = 'SQL ץ';
$strSQLParserBugMessage = 'ʤ SQL ѡΥХ򸫤뤫⤷ޤ󡣤ʤ䤤碌ǰ˳Τơ䤬ߥޥåʤåޤ礦¾μԤˤϥƥȥꥢǰѤ¦˥Хʥ꡼ɤդƥե뤬åץɤƤޤä褦ʸͤޤޤʤ䤤碌 MySQL Υޥɥ饤ȤäƻȤǤޤMySQL ФϰʲΤ褦˥顼Фޤˤ褹Ǥ礦ޥɥ饤ǤƤ⡢ޤ꤬硢ѡԤˤϡΤ SQL 䤤碌ҤȤĤʸ˸餷ƤߤƲưʲΥǥǡڤäƥХäƲ:';
$strSQLParserUserError = 'SQL ˥顼ޤMySQL ФϰʲΤ褦˥顼Ϥޤˤ褹Ǥ礦';
$strSQLQuery = '¹Ԥ SQL';
$strSQLResult = 'SQL η';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'ǧڤ̵Ǥ';
$strSQPBugUnclosedQuote = '䤬ĤƤޤ';
$strSQPBugUnknownPunctuation = '̵ʶʸǤ';
$strStatCheckTime = 'ǽ';
$strStatCreateTime = '';
$strStatement = 'ơȥ';
$strStatisticsOverrun = 'ӥʥФǤϡХȥ󥿤Ķ᤹뤫⤷ޤ󡣽äơMySQL Ф𤹤뤽פʤ⤷ޤ';
$strStatUpdateTime = 'ǽ';
$strStatus = '';
$strStorageEngine = 'ȥ졼󥸥';
$strStorageEngines = 'ȥ졼󥸥';
$strStrucCSV = 'CSV ǡ';
$strStrucData = '¤ȥǡ';
$strStrucExcelCSV = 'MS Excel  CSV ǡ';
$strStrucNativeExcel = ' MS Excel ǡ';
$strStrucNativeExcelOptions = 'ExcelΥͥƥ֥ݡȤΥץ';
$strStrucOnly = '¤Τ';
$strStructPropose = 'ơ֥빽¤ǧ';
$strStructure = '¤';
$strSubmit = '¹Ԥ';
$strSuccess = 'SQL ˼¹Ԥޤ';
$strSum = '';
$strSwedish = 'ǥ';
$strSwitchToDatabase = 'ԡǡ١ڤؤ';
$strSwitchToTable = 'ԡơ֥ڤؤ';

$strTable = 'ơ֥ ';
$strTableAlreadyExists = 'ơ֥ %s ϴ¸ߤޤ!';
$strTableComments = 'ơ֥';
$strTableEmpty = 'ơ֥϶Ǥ';
$strTableHasBeenDropped = 'ơ֥ %s ޤ';
$strTableHasBeenEmptied = 'ơ֥ %s ˤޤ';
$strTableHasBeenFlushed = 'ơ֥ %s Υåˤޤ';
$strTableMaintenance = 'ơ֥';
$strTableOfContents = 'ơ֥';
$strTableOptions = 'ơ֥륪ץ';
$strTables = '%sơ֥';
$strTableStructure = 'ơ֥ι¤';
$strTakeIt = 'ˤޤ';
$strTblPrivileges = 'ơ֥ ø';
$strTempData = 'ǡ';
$strTextAreaLength = ' Ĺν٤ǤΥեɤ<br /> Ǥʤǽޤ';
$strThai = '';
$strTheme = 'ơ / ';
$strThemeDefaultNotFound = 'ǥեȥơޡ%sĤޤ!';
$strThemeNoPreviewAvailable = 'ץӥ塼ѤǤޤ';
$strThemeNotFound = 'ơޡ%sĤޤ!';
$strThemeNoValidImgPath = 'ơޡ%sѥĤޤ!';
$strThemePathNotFound = 'ơޡ%sΥơޥѥĤޤ!';
$strThisHost = 'Υۥ';
$strThisNotDirectory = 'ϥǥ쥯ȥǤϤޤ';
$strThreads = 'å';
$strThreadSuccessfullyKilled = 'å %s Ͻλޤ';
$strTime = '';
$strTimeoutInfo = '˥ݡȤǥॢȤƤޤ塢 %d ³Ǥ礦';
$strTimeoutNothingParsed = 'Ǹμ¹ԤǤΥǡϲϤƤޤ󡣤ϡ̾ php λ¤䤵ʤ phpMyAdmin ΥݡȤλ뤳ȤǤʤȤȤ̣ޤ';
$strTimeoutPassed = 'ץȤॢȤ᤮ޤݡȤ򽪤餻硢ƱեݡȤƳƤ';
$strToggleScratchboard = 'ȥ륹åܡ';
$strTotal = '';
$strTotalUC = '';
$strTraditionalChinese = 'Ū';
$strTraditionalSpanish = 'Ūʥڥ';
$strTraffic = 'ȥեå';
$strTransactionCoordinator = 'ȥ󥶥󥳡ǥ͡';
$strTransformation_application_octetstream__download = 'եɤΥХʥǡɤ󥯤ɽޤ1 ܤΥץϥХʥեΥեǤ2 ܥץϥեޤơ֥ԤեɤǤ2 ܤΥץ󶡤硢1 ܤΥץ϶ʸꤹɬפޤ';
$strTransformation_application_octetstream__hex = 'ǡ 16 ʿɽǤ';
$strTransformation_image_jpeg__inline = 'åǽʥͥɽޤ; ץ: widthheight ԥǻ (Ψݤޤ)';
$strTransformation_image_jpeg__link = 'βؤΥ󥯤ɽ (㤨 blob ľܥ).';
$strTransformation_image_png__inline = 'image/jpeg: inline򻲾ȤƤ';
$strTransformation_text_plain__dateformat = 'TIMETIMESTAMP 뤤 DATETIME եɤǡɽѤƽ񼰲ޤ1 ܤΥץϥॹפ˲û륪եåȻ(ñ:)Ǥ(ǥե: 0)2 ܤΥץϡPHP  strftime()Ѳǽʥѥ᡼ǤΤޤޤɽǤ';
$strTransformation_text_plain__external = 'LINUX Τ: ץꥱưɸϤեɥǡϤޤץꥱɸϤ֤ޤǥեȤ Tidy ǡ HTML ɤϤޤƥͳǡưǥեlibraries/text_plain__external.inc.phpԽ¹ԤĤġʤФʤޤ󡣺ǽΥץϡѤץοǡ2 ܤΥץϥץΥѥ᡼Ǥ3 ܤΥץ 1 ꤵƤ硢htmlspecialchars() ѤƽϤѴǤ礦(ǥե: 1)4  ץ 1 ꤵƤ硢§ɤϤ٤ 1 Ԥ˸뤳ȤݾڤǤ礦(ǥե: 1).';
$strTransformation_text_plain__formatted = 'եɤθν񼰤¸ޤפ˽λޤ';
$strTransformation_text_plain__imagelink = 'ȥ󥯡եޤեɤɽޤ; 1 ܤΥץ "http://domain.com/" Τ褦Ƭǡ2 ܤΥץϥԥ3 ܤϹ⤵Ǥ';
$strTransformation_text_plain__link = 'եޤեɡ󥯤ɽ; 1 ܤΥץ "http://domain.com/" Τ褦Ƭ졢2 ܤΥץϥ󥯤ΥȥǤ';
$strTransformation_text_plain__sql = 'SQL Ҳ ȤƥƥȤηʸˡϥ饤Ȥޤ';
$strTransformation_text_plain__substr = 'ʸΰΤɽޤ1 ܤΥץϥƥȤνϤɤǳϤ뤫եåȤޤ (ǥեȤϡ0Ǥ)2 ܤΥץϤɤΥƥȤ֤ΥեåȤǤξ硢ĤΥƥȤ򤹤٤֤ޤ3 ܤΥץϡʸΰ֤ɤʸϤɲä뤫ޤ (ǥեȤϡ...Ǥ)';
$strTruncateQueries = 'Ȳɽڤͤ';
$strTurkish = 'ȥ륳';
$strType = 'եɥ';

$strUkrainian = '饤ʸ';
$strUncheckAll = 'å򤹤٤ƺ';
$strUnicode = 'UNICODE';
$strUnique = '';
$strUnknown = '';
$strUnselectAll = '';
$strUnsupportedCompressionDetected = 'ݡȤƤʤ̷(%s)Υեɤ߹ߤߤޤμݡȤƤʤ̵ˤʤäƤ뤫Τ줫Ǥ';
$strUpdatePrivMessage = '%s ø򹹿ޤ';
$strUpdateProfileMessage = 'ץե򹹿ޤ';
$strUpdateQuery = 'Ȳ򹹿';
$strUpdComTab = 'Column_comments ơ֥Υåץ졼ˡΥɥȤ򻲾ȤƤ';
$strUpgrade = '%s %s ʹߤ˥åץ졼ɤƤ';
$strUploadLimit = '餯ޤˤ礭ʥե򥢥åץɤ褦Ȥޤ¤βʤȤ %sɥ%s 򻲾ȤƤ';
$strUploadsNotAllowed = 'ΥФǤϥեΥåץɤؤƤޤ';
$strUsage = '';
$strUseBackquotes = 'եȤǥơ֥եɤϤ';
$strUsedPhpExtensions = ' PHP ĥ';
$strUseHostTable = 'ۥȥơ֥Ȥ';
$strUserAlreadyExists = '桼%sϴ¸ߤޤ!';
$strUser = '桼';
$strUserEmpty = '桼϶Ǥ';
$strUserName = '桼';
$strUserNotFound = '򤵤줿桼øơ֥˸ĤޤǤ';
$strUserOverview = '桼ά';
$strUsersDeleted = '򤵤줿桼Ϻޤ';
$strUsersHavingAccessToDb = '桼 &quot;%s&quot; ؤΥ¤Ƥޤ';
$strUseTabKey = 'ͤͤޤǰܤˤ TAB 򡢤⤷ϤʾǤưˤ CTRL + Ѥޤ';
$strUseTables = 'Ȥơ֥';
$strUseTextField = 'ƥȥեɤ';
$strUseThisValue = 'ͤ';

$strValidateSQL = 'SQL θ';
$strValidatorError = 'SQL θڵǽǤޤ%sɥ%s ˵ҤƤ褦 PHP ĥ饤֥꤬󥹥ȡ뤵Ƥ뤫åƤ';
$strValue = '';
$strVar = 'ѿ';
$strVersionInformation = 'С';
$strView = 'ӥ塼';
$strViewDump = 'ơ֥Υ()ɽ';
$strViewDumpDatabases = 'ǡ١Υץӥ塼 ()';
$strViewDumpDB = 'DB Υ()ɽ';
$strViewHasBeenDropped = 'ӥ塼 %s ˴ޤ';
$strViewMaxExactCount = 'Υӥ塼 %s ʾ夢ޤ%sɥ%s 򻲾ȤƤ';

$strWebServerUploadDirectory = '֥оǥåץɤ';
$strWebServerUploadDirectoryError = 'åץɤԤǥ쥯ȥ꤬ޤ';
$strWelcome = '%s ؤ褦';
$strWestEuropean = '衼åѸ';
$strWildcard = '磻ɥ';
$strWindowNotFound = 'åȥ֥饦ɥ򹹿뤳ȤǤޤ󡣶餯ƥɥĤ뤤ϥ֥饦Υƥǡɥι֥åƤޤ';
$strWithChecked = 'åΤ:';
$strWriteRequests = '񤭹ߥꥯȿ';
$strWritingCommentNotPossible = 'Ȥν񤭹ߤͭǤϤޤ';
$strWritingRelationNotPossible = '졼ν񤭹ߤͭǤϤޤ';
$strWrongUser = '桼ޤϥѥɤޤ<br />ϵݤޤ';

$strXkana = 'ѥʤѴ'; // convert to X208-kana
$strXMLOptions = 'XMLץ';
$strXML = 'XML';

$strYes = 'Ϥ';

$strZeroRemovesTheLimit = ': ץ 0 ()ꤹ¤ʤʤޤ';
$strZip = '"zip "';

?>
